!****************************************************************************
!   Irr_Demand.f90 
!       
!
!   Program 1 of the COHYST SUITE of programs
!   
!   Purpose:
!   Develop the irrigation demand for ground water, surface water , and
!   co-minlged lands.
!
!   Development log:
!   January 2014, Isaac Mortensen - TFG
!       
!    
!****************************************************************************
!   
!   ADJdp       - An adjustment factor to the DP coming out of CropSim, residual to non-beneficial consumptive use
!   ADJetdry    - An ajdustment to the ET of dryland crops for non-idealized coniditions
!   ADJetirr    - An adjustment to the ET of irrigated crops for non-idealized conidtions
!   ADJnir      - Changes target NIR
!   ADJro       - An adjustment factor to the RO coming out of CropSim, residual to non-beneficial consumptive use
!   AEfile      - Name of the application efficieny file
!   Cellloc     - Name of the cell location file
!   CNLDIR      - Canal Directory
!   Coeffile    - Name of the Adjustment coefficients file
!   CoefZ       - Coefficient zone for the cell
!   COLU        - Co-mingled land use file prefix
!   COLUfld     - Folder containing the co-mingled land use information
!   cRun        - Run name
!   DPcap       - The hypothetical maximum DP
!   DPLL        - The depth at which the DP begins to taper off
!   DryET2RO    - Partitioning factor of the ET adjustment between DP and RO
!   DryLU       - Dryland land use file prefix
!   DryLUfld    - Folder containing the dryland land use information
!   endyr       - Final year of the simulation
!   Fslgw       - Evaporative losses during the application of ground water irrigation
!   Fslsw       - Evaporative losses during the application of surface water irrigation
!   GWCfld      - Location of the ground water conctration files
!   GWCfile     - Ground water contcentration file prefix
!   GWLU        - Ground water land use file prefix
!   GWLUfld     - Folder containing the ground land use information
!   INDIR       - Location of the input files
!   LUDIR       - Location of the land use information
!   M2G         - Distance between cell centroid and stream gauge
!   ncells      - Number of cells in the complete model grid
!   ncrops      - Number of crops included in the simulation
!   nczones     - Number of coefficient zones
!   nirrdist    - Number of irrigation districts
!   nrzones     - Number of runoff zones
!   nsoils      - Number of soil classes
!   OUTDIR      - Location for the simulation results
!   ROfDP       - Factor used to skew the weighting of the partitioning fact
!   ROmax       - Maximum partitioning ratio
!   ROmin       - Minimum partitioning ratio
!   ROZ         - Runoff zone for the cell
!   ROZfile     - Name of the RunoffZone file
!   startyr     - Beginning year of the simulation
!   Soil        - Soil index number for the cell
!   SWLU        - Surface water land use file prefix
!   SWLUfld     - Folder containing the surface water land use information
!   WBPDIR      - Location of the gridded CropSim results
!   
!   
!   Crops:
!       1. Corn
!       2. Soybeans
!       3. Sorghum (Milo)
!       4. Alfalfa
!       5. Winter Wheat
!       6. Pasture
!       7. Fallow
!       8. Miscellaneous
!
!****************************************************************************
MODULE PARAM

    DATA MasterDIR /'W:\COHYST\COHYST\Run028\Run028b2\Inputs\'/
    DATA MasterFile /'MasterInput_v27.1.txt'/

    CHARACTER*12, ALLOCATABLE ::    Crops(:)
    
    CHARACTER*1000  INDIR, OUTDIR, WBPDIR, LUDIR, CNLDIR, MasterDIR
    CHARACTER*1000  MISCDIR, MIDIR
    CHARACTER*250   GWLUfld, SWLUfld, COLUfld, DryLUfld, GWCfld
    CHARACTER*250   GWLU, SWLU, COLU, DryLU, cRun, MODname
    CHARACTER*250   CellLoc, Coeffile, AEfile, ROZfile, GWCfile, MasterFile
    CHARACTER*250   PctRchfile, SWidxfile, CountID, Cell_county
    CHARACTER*250   cnlmastfile, miscrmastfile, miscpmastfile, mirmastfile, mipmastfile
    CHARACTER*250   ActCellFile
    !Added 1/7/2016
    CHARACTER*250   Callyrfile
    
    INTEGER     ncells, nczones, nrzones, nsoils, nirrdist, ncrops
    INTEGER     startyr, endyr, DPonly, SWonly
    INTEGER     ncols, nrows, cnlrflg, miscrflg, miscpflg, mirflg, mipflg
    INTEGER     Rch0flg
    !Added 1/7/2016
    INTEGER     ctrlyrs
    
    REAL    csize
    
    CHARACTER*4     YRT
    CHARACTER*3     Mon(0 : 12)
    !Added 1/7/2016
    CHARACTER*4     YRTlu, YRTwbp, YRTgwc
    
    INTEGER     z, c, s, i, j, k
    INTEGER     ii, jj, kk
    INTEGER     zone, swdist, cell
    INTEGER     iyear, pflag
    INTEGER     yr, irrdist, swdistidx
    INTEGER     sidx(56), indx, icrop, dummy
        
    REAL    NIR(0 : 12)
    REAL    GWPcell(0 : 12), SWDcell(0 : 12), CODcell(0 : 12), COPcell(0 : 12)
    REAL    totacs
    
    DOUBLE PRECISION    AnnID(4)
    
    INTEGER, ALLOCATABLE :: soil(:), CoefZ(:), ROZ(:)
    !Added 1/7/2016
    INTEGER, ALLOCATABLE :: LUyear(:), WBPyear(:), GWCyear(:)
    INTEGER, Allocatable :: yrctrl(:)
    
    REAL, ALLOCATABLE :: M2G(:)
    REAL, ALLOCATABLE :: ADJnir(:,:,:), ADJetdry(:,:,:), ADJetirr(:,:,:), Fslgw(:,:,:)
    REAL, ALLOCATABLE :: Fslsw(:,:,:), DryET2RO(:,:,:), ADJdp(:,:,:)
    REAL, ALLOCATABLE :: ADJro(:,:,:), ROmax(:,:,:), ROmin(:,:,:)
    REAL, ALLOCATABLE :: DPLL(:,:,:), DPcap(:,:,:), ROfDP(:,:,:)
    REAL, ALLOCATABLE :: AEgwb(:, :), AEgyr(:, :), AEswb(:, :), AEsyr(:, :)
    REAL, ALLOCATABLE :: GWC(:), LatLoss(:)
    
    REAL, ALLOCATABLE :: NIRCS(:, :, :), Precip(:, :)
    REAL, ALLOCATABLE :: GWP(:, :), SWD(:,:), COD(:, :), COP(:, :)
    REAL, ALLOCATABLE :: GWac(:), SWac(:), COac(:)
    REAL, ALLOCATABLE :: AEgw(:), AEsw(:)
    
    DATA Mon /'Ann', 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'/

END MODULE PARAM
!****************************************************************************
PROGRAM Irr_Demand
    USE PARAM
    IMPLICIT NONE

    OPEN (1, FILE = TRIM(MasterDIR)//TRIM(MasterFile), STATUS = 'OLD')
    READ (1, *)

    READ (1, *) cRun
    READ (1, *) MODname
    READ (1, *) INDIR
    READ (1, *) OUTDIR
    READ (1, *) WBPDIR
    READ (1, *) LUDIR
    READ (1, *) CNLDIR
    READ (1, *) MiscDIR
    READ (1, *) MIDIR
    READ (1, *) GWLUfld
    READ (1, *) SWLUfld
    READ (1, *) COLUfld
    READ (1, *) DryLUfld
    READ (1, *) GWLU
    READ (1, *) SWLU
    READ (1, *) COLU
    READ (1, *) DryLU
    READ (1, *) GWCfld
    READ (1, *) GWCfile
    READ (1, *) CellLoc
    READ (1, *) Coeffile
    READ (1, *) AEfile
    READ (1, *) ROZfile
    READ (1, *) PctRchfile
    READ (1, *) SWidxfile
    READ (1, *) CountID
    READ (1, *) Cell_county
    READ (1, *) CNLmastfile
    READ (1, *) MISCrmastfile
    READ (1, *) MISCpmastfile
    READ (1, *) MIrmastfile
    READ (1, *) MIpmastfile
    READ (1, *) ActCellfile
    !Added 1/7/2016
    READ (1, *) CallYrfile
    READ (1, *) ncells
    READ (1, *) startyr
    READ (1, *) endyr
    READ (1, *) RCH0flg
    READ (1, *) DPonly
    READ (1, *) SWonly
    READ (1, *) cnlrflg
    READ (1, *) miscrflg
    READ (1, *) miscpflg
    READ (1, *) MIrflg
    READ (1, *) MIpflg
    !Added 1/7/2016
    READ (1, *) ctrlyrs
    READ (1, *) nczones
    READ (1, *) nrzones
    READ (1, *) nsoils
    READ (1, *) nirrdist
    READ (1, *) csize
    READ (1, *) ncols
    READ (1, *) nrows
    READ (1, *) ncrops
    
    ALLOCATE (Crops(ncrops))
    
    DO i = 1, ncrops
        READ (1, *) crops(i)
    END DO
    CLOSE (1)
    
    ALLOCATE (soil(ncells), CoefZ(ncells), ROZ(ncells), M2G(ncells))
    ALLOCATE (ADJnir(nczones, ncrops, nsoils), ADJetdry(nczones, ncrops, nsoils), ADJetirr(nczones, ncrops, nsoils))
    ALLOCATE (Fslgw(nczones, ncrops, nsoils), Fslsw(nczones, ncrops, nsoils), DryET2RO(nczones, ncrops, nsoils))
    ALLOCATE (ADJdp(nczones, ncrops, nsoils), ADJro(nczones, ncrops, nsoils), ROmax(nczones, ncrops, nsoils), ROmin(nczones, ncrops, nsoils))
    ALLOCATE (DPLL(nczones, ncrops, nsoils), DPcap(nczones, ncrops, nsoils), ROfDP(nczones, ncrops, nsoils))
    ALLOCATE (AEgwb(nczones, 2), AEgyr(nczones, 2), AEswb(nczones, 2), AEsyr(nczones, 2))
    ALLOCATE (GWC(nirrdist), LatLoss(nirrdist))
    ALLOCATE (NIRCS(ncells, ncrops, 0 : 12))
    ALLOCATE (GWP(ncrops, 0 : 12), SWD(ncrops, 0 : 12), COD(ncrops, 0 : 12), COP(ncrops, 0 : 12))
    ALLOCATE (GWac(ncrops), SWac(ncrops), COac(ncrops))
    ALLOCATE (AEgw(nczones), AEsw(nczones))
    ALLOCATE (Precip(ncells, 0 : 12))
    
    !Added 1/7/2016
    ALLOCATE (yrctrl(ctrlyrs))
    ALLOCATE (LUyear(startyr : endyr), WBPyear(startyr : endyr), GWCyear(startyr : endyr))
    
    OUTDIR = TRIM(OUTDIR)//TRIM(cRun)//'\Results\'
    
    !Populate cell soils, zones, and location
    WRITE (6, *) 'Reading Cell Location'
    OPEN (1, FILE = TRIM(INDIR)//TRIM(CellLoc), STATUS = 'OLD')
    READ (1, *)
    DO WHILE (.NOT. EOF(1))
        READ (1, *) cell, Soil(cell), CoefZ(cell), ROZ(cell), M2G(cell)
    END DO
    CLOSE (1)
    
    !Load coefficient zone coefficients
    !z - zone
    !c - crop
    !s - soil
    WRITE (6, *) 'Reading Coefficient Zone Parameters'
    OPEN (1, FILE = TRIM(INDIR)//TRIM(Coeffile), STATUS = 'OLD')
    READ (1, *)
    DO WHILE (.NOT. EOF(1))
        READ (1, *) z, c, s, ADJnir(z, c, s), ADJetdry(z, c, s), ADJetirr(z, c, s), &
                        Fslgw(z, c, s), Fslsw(z, c, s), DryET2RO(z, c, s), &
                        ADJdp(z, c, s), ADJro(z, c, s), ROmax(z, c, s), ROmin(z, c, s), &
                        DPLL(z, c, s), DPcap(z, c, s), ROfDP(z, c, s)
    END DO
    CLOSE (1)
    
    !Load application efficiencies
    WRITE (6, *) 'Loading Application Efficiencies'
    OPEN (1, FILE = TRIM(INDIR)//TRIM(AEfile), STATUS = 'OLD')
    READ (1, *)
    DO WHILE (.NOT. EOF(1))
        READ (1, *) zone, AEgwb(zone, :), AEgyr(zone, :), AEswb(zone, :), AEsyr(zone, :)
    END DO
    CLOSE (1)
    
    sidx = 0
    !Read SWIndex
    OPEN (1, FILE = TRIM(INDIR)//TRIM(SWidxfile), STATUS = 'OLD')
    READ (1, *)
    DO WHILE (.NOT. EOF(1))
        READ (1, *) indx, swdist
        sidx(swdist) = indx    
    END DO
    CLOSE (1)
    
    !Read in Call year
    !Added 1/7/2016 to control the annual input data and allow the same data to be applied to different years
    !ex: applying a fixed land use to the historical climate
    OPEN (1, FILE = TRIM(INDIR)//TRIM(CallYrFile), STATUS = 'OLD')
    READ (1, *)
    DO WHILE (.NOT. EOF(1))
        READ (1, *) yr, yrctrl
        IF ((yr .GE. startyr) .AND. (yr .LE. endyr)) THEN
            LUyear(yr) = yrctrl(1)
            WBPyear(yr) = yrctrl(2)
            GWCyear(yr) = yrctrl(3)
        END IF
    END DO
    CLOSE (1)
    
    OPEN (30, FILE = TRIM(OUTDIR)//'DemIrr/Irrtrans.txt', STATUS = 'UNKNOWN')
    WRITE (30, 300)
    
    OPEN(40, FILE = TRIM(OUTDIR)//'Demand_sum.txt', STATUS = 'UNKNOWN')
    WRITE (40, 400)
    
    !Added 1/7/2016
    WRITE (6, 600) 
    
    !Annual Loop
    DO iyear = startyr, endyr
        !Altered 1/7/2016
        WRITE (6, 601) iyear, LUyear(iyear), WBPyear(iyear), GWCyear(iyear)
        WRITE (YRT, '(I4)') iyear
        
        !Added 1/7/2016
        WRITE (YRTlu, '(I4)') LUyear(iyear)
        WRITE (YRTwbp, '(I4)') WBPyear(iyear)
        WRITE (YRTgwc, '(I4)') GWCyear(iyear)
        
        CALL GetAE
        
        AnnID = 0.
        
        GWC = 0.
        LatLoss = 0.
        !Load ground water concentration and lateral loss parameters
        !Updated YRTgwc 1/7/2016
        OPEN (1, FILE = TRIM(INDIR)//TRIM(GWCfld)//'\'//TRIM(GWCfile)//Trim(YRTgwc)//'.txt', STATUS = 'OLD')
        READ (1, *) 
        DO WHILE (.NOT. EOF(1))
            READ (1, *) yr, irrdist, GWC(sidx(irrdist)), LatLoss(sidx(irrdist))
        END DO
        CLOSE (1)
        
        CALL CSFiles
        
        Precip = 0.
        !Updated YRTwbp 1/7/2016
        OPEN (1, FILE = TRIM(WBPDIR)//'Precip\PRECIP'//TRIM(YRTwbp)//'.txt', STATUS = 'OLD')
        READ (1, *)
        DO WHILE (.NOT. EOF(1))
            READ (1, *) cell, yr, icrop, Precip(cell, 0 : 12)
            Precip(cell, 0) = SUM(Precip(cell, 1 : 12))
        END DO 
        CLOSE (1)        
        
        OPEN (10, FILE = TRIM(OUTDIR)//'DemIrr/GWP/GWP'//TRIM(YRT)//'.txt', STATUS = 'UNKNOWN')
        OPEN (11, FILE = TRIM(OUTDIR)//'DemIrr/SWD/SWD'//TRIM(YRT)//'.txt', STATUS = 'UNKNOWN')
        OPEN (12, FILE = TRIM(OUTDIR)//'DemIrr/COD/COD'//TRIM(YRT)//'.txt', STATUS = 'UNKNOWN')
        OPEN (13, FILE = TRIM(OUTDIR)//'DemIrr/COP/COP'//TRIM(YRT)//'.txt', STATUS = 'UNKNOWN')
        OPEN (14, FILE = TRIM(OUTDIR)//'DemIrr/HDRSW/SWdist'//TRIM(YRT)//'.txt', STATUS = 'UNKNOWN')
        
        WRITE (10, 100) (Mon(i), i = 0, 12)
        WRITE (11, 101) (Mon(i), i = 0, 12)
        WRITE (12, 103) (Mon(i), i = 0, 12)
        WRITE (13, 102) (Mon(i), i = 0, 12)
        WRITE (14, 104) (Mon(i), i = 0, 12)
        
        OPEN (20, FILE = TRIM(OUTDIR)//'SWIDsum/SWIDsum'//TRIM(YRT)//'.txt', STATUS = 'UNKNOWN')
        WRITE (20, 200)
        
        ii = 0
        pflag = 2
        !GW Loop
        !Updated YRTlu 1/7/2016
        OPEN (1, FILE = TRIM(LUDIR)//TRIM(GWLUfld)//'\'//TRIM(GWLU)//TRIM(YRTlu)//'.txt', STATUS = 'OLD')
        READ (1, *)
        DO WHILE (.NOT. EOF(1))
            READ (1, *) cell, yr, totacs, GWac
            GWPcell = 0.
            GWP = 0.
            
            DO j = 1, ncrops - 2
                IF (GWac(j) .GT. 0.) THEN
                    NIR = MAX(NIRCS(cell, j, :), 0.)
                    NIR(0) = SUM(NIR(1 : 12))
                
                    GWP(j, :) = NIR * ADJnir(CoefZ(cell), j, soil(cell)) / (12 * AEgw(Coefz(cell))) * GWac(j)
                    GWP(j, 0) = SUM(GWP(j, 1 : 12))
                    GWPcell(1 : 12) = GWPcell(1 : 12) + GWP(j, 1 : 12)
                    
                    ii = ii + 1
                    WRITE (10, 110) ii, Cell, iyear, j, GWP(j, :)
                END IF
            END DO
            
            AnnID(pflag - 1) = AnnID(pflag - 1) + SUM(GWPcell(1 : 12)) 
            
        END DO
        CLOSE (1)
        CLOSE (10)
        
        Dummy = 0.
        jj = 0
        pflag = 3
        !SW Loop
        !Updated YRTlu 1/7/2016
        OPEN (1, FILE = TRIM(LUDIR)//TRIM(SWLUfld)//'\'//TRIM(SWLU)//TRIM(YRTlu)//'.txt', STATUS = 'OLD')
        READ (1, *)
        DO WHILE (.NOT. EOF(1))
            READ (1, *) cell, yr, swdist, swdistidx, totacs, SWac
            SWD = 0.
            SWDcell = 0.
            
            DO j = 1, ncrops - 2
                IF (SWac(j) .GT. 0.) THEN
                    NIR = MAX(NIRCS(cell, j, :), 0.)
                    NIR(0) = SUM(NIR(1 : 12))
                            
                    SWD(j, :) = NIR * ADJnir(Coefz(cell), j, soil(cell)) / (12 * AEsw(Coefz(cell))) * SWac(j) * (1 + LatLoss(swdistidx))
                    SWD(j, 0) = SUM(SWD(j, 1 : 12))
                    SWDcell(1 : 12) = SWDcell(1 : 12) + SWD(j, 1 : 12)
                            
                    WRITE (20, 201) cell, iyear, swdist, swdistidx, Coefz(cell), j, soil(cell), SWac(j), Dummy, Precip(cell, 0), &
                                        NIR(0) * ADJnir(Coefz(cell), j, soil(cell)) / AEsw(Coefz(cell)), &
                                        NIR(0) * ADJnir(Coefz(cell), j, soil(cell)) / (12 * AEsw(Coefz(cell))) * SWac(j), &
                                        LatLoss(swdistidx), SWD(j, 0), Dummy
                    jj = jj + 1
                    WRITE (11, 111) jj, cell, iyear, swdist, swdistidx, j, SWD(j, :)
                END IF            
            END DO
            
            SWDcell(0) = SUM(SWDcell(1 : 12))
!            j = 0
!            WRITE (11, 111) j, Cell, iyear, swdist, swdistidx, j, SWDcell(:)

            AnnID(pflag - 1) = AnnID(pflag - 1) + SWDcell(0)

            WRITE (14, 112) Cell, iyear, swdist, swdistidx, pflag, SWDcell
            
        END DO
        CLOSE (1)
        CLOSE (11)
        
        !SWac(1) = 0.
        kk = 0
        pflag = 4
        !Co-mingled Loop
        !Updated YRTlu 1/7/2016
        OPEN (1, FILE = TRIM(LUDIR)//TRIM(COLUfld)//'\'//TRIM(COLU)//TRIM(YRTlu)//'.txt', STATUS = 'OLD')
        READ (1, *)
        DO WHILE (.NOT. EOF(1))
            READ (1, *) cell, yr, swdist, swdistidx, totacs, coac
            COP = 0.
            COPcell = 0.
            COD = 0.
            CODcell = 0.
            
            DO j = 1, ncrops - 2
                IF (COac(j) .GT. 0.) THEN
                    NIR = MAX(NIRCS(cell, j, :), 0.)
                    NIR(0) = SUM(NIR(1 : 12))
                        
                    COD(j, :) = NIR * ADJnir(coefz(cell), j, soil(cell)) / (12 * AEsw(Coefz(cell))) * COac(j) * (1 - GWC(swdistidx)) * (1 + LatLoss(swdistidx))
                    COD(j, 0) = SUM(COD(j, 1 : 12))
                    CODcell(1 : 12) = CODcell(1 : 12) + COD(j, 1 : 12)
                        
                    COP(j, :) = NIR * ADJnir(coefz(cell), j, soil(cell)) / (12 * AEgw(Coefz(cell))) * COac(j) * GWC(swdistidx)
                    COP(j, 0) = SUM(COP(j, 1 : 12))
                    COPcell(1 : 12) = COPcell(1 : 12) + COP(j, 1 : 12)

                    WRITE (20, 201) cell, iyear, swdist, swdistidx, Coefz(cell), j, soil(cell), Dummy, CoAc(j), Precip(cell, 0), &
                                        NIR(0) * ADJnir(coefz(cell), j, soil(cell)) / AEsw(Coefz(cell)), &
                                        NIR(0) * ADJnir(coefz(cell), j, soil(cell)) / (12 * AEsw(Coefz(cell))) * COac(j) * (1 - GWC(swdistidx)), &
                                        LatLoss(swdistidx), COD(j, 0), GWC(swdistidx)
                                        
                    kk = kk + 1
                    WRITE (12, 111) kk, cell, iyear, swdist, swdistidx, j, COD(j, :)
                    WRITE (13, 111) kk, cell, iyear, swdist, swdistidx, j, COP(j, :)

                END IF
            END DO

!            j = 0

!            WRITE (12, 111) j, Cell, iyear, swdist, swdistidx, j, CODcell
                    
            COPcell(0) = SUM(COPcell(1 :12))
!            WRITE (13, 111) j, Cell, iyear, swdist, swdistidx, j, COPcell
            CODcell(0) = SUM(CODcell(1 : 12))
            
            AnnID(pflag - 1) = AnnID(pflag - 1) + COPcell(0)
            AnnID(pflag) = AnnID(pflag) + CODcell(0)
            
            WRITE (14, 112) Cell, iyear, swdist, swdistidx, pflag, CODcell

        END DO
        CLOSE (1)
        CLOSE (12)
        CLOSE (13)
        
        CLOSE (14)
        CLOSE (20)
       
        WRITE (30, 301) iyear, ii, jj, kk
        WRITE (40, 401) iyear, AnnID
    END DO
    
    CLOSE (30)
    
100 FORMAT ('Index, Cell, Year, crop', 13(', GWP_', A3))
101 FORMAT ('Index, Cell, Year, District, SW_index, Crop', 13(', SWD_', A3))
102 FORMAT ('Index, Cell, Year, District, SW_index, Crop', 13(', COP_', A3))
103 FORMAT ('Index, Cell, Year, District, SW_index, Crop', 13(', COD_', A3))
104 FORMAT ('Cell, Year, District, SW_index, Irr_Source', 13(', DemSW_', A3))
    
110 FORMAT (2(I7, ','), I5, ',', I4, 13(',', F14.7))
111 FORMAT (2(I7, ','), I5, 3(',', I4), 13(',', F14.7))
112 FORMAT (I7, ',', I5, 3(',', I4), 13(',', F14.7))
    
200 FORMAT ('Cell, CalcYr, CanalDistrict, Canaldistrictindex, Zone, Crop, Soil, SWOnlyAcres, CommingledAcres, Precip, ' &
            'CropDemand_in, CropDemand_AF, LateralLossPercent, DivDemand_AF, GWC')
201 FORMAT (I7, ',', I5, 5(',', I4), 5(',', F8.2), ',', F5.2, ',', F8.2, ',', F5.2)
    
300 FORMAT ('Year, GWtrans, SWtrans, COtrans')
301 FORMAT (I5, 3(',', I7))
    
400 FORMAT ('Year, GWP, SWD, COP, COD')
401 FORMAT (I5, 4(',', F14.2))    
    
!Added 1/7/2016
600 FORMAT (' Sim Year,  LU Year, WBP Year, GWC Year')
601 FORMAT (I9, 3(',', I9))
    
END Program Irr_Demand
!****************************************************************************

SUBROUTINE CSFiles
    USE PARAM
    IMPLICIT NONE
    
    !Variables
    INTEGER     nn, crp
    
    NIRCS = 0.

    DO nn = 1, ncrops - 2
        !Updated YRTwbp 1/7/2016
        OPEN (100, FILE = TRIM(WBPDIR)//'NIR\'//Trim(Crops(nn))//'-NIR'//TRIM(YRTwbp)//'.txt', STATUS = 'OLD')
        READ (100, *)
        DO WHILE (.NOT. EOF(100)) 
            READ (100, *) cell, yr, crp, (NIRCS(cell, nn, i), i = 0, 12)
        END DO
        CLOSE (1)
    END DO
    
END SUBROUTINE CSFiles
!****************************************************************************
SUBROUTINE GetAE
    USE PARAM

    !Variables
    INTEGER izone
    
    DO izone = 1, nczones
        IF (iyear .LE. AEgyr(izone, 1)) THEN
            AEgw(izone) = AEgwb(izone, 1)
        ELSE IF (iyear .GE. AEgyr(izone, 2)) THEN
            AEgw(izone) = AEgwb(izone, 2)
        ELSE
            AEgw(izone) = AEgwb(izone, 1) + (AEgwb(izone, 2) - AEgwb(izone, 1)) * ((iyear - AEgyr(izone, 1)) / (AEgyr(izone, 2) - AEgyr(izone, 1)))
        END IF
    
        IF (iyear .LE. AEsyr(izone, 1)) THEN
            AEsw(izone) = AEswb(izone, 1)
        ELSE IF (iyear .GE. AEsyr(izone, 2)) THEN
            AEsw(izone) = AEswb(izone, 2)
        ELSE
            AEsw(izone) = AEswb(izone, 1) + (AEswb(izone, 2) - AEswb(izone, 1)) * ((iyear - AEsyr(izone, 1)) / (AEsyr(izone, 2) - AEsyr(izone, 1)))
        END IF
    END DO
    
END SUBROUTINE GetAE
!****************************************************************************